from ops import (cholesky, matrix_inverse, solve,
        diag, extract_diag, alloc_diag,
        det, psd, eig, eigh, eigvalsh,
        trace, spectral_radius_bound)
